summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNguyen Van Trung <trungnv@vn.fujitsu.com>2018-07-26 10:29:41 +0700
committerNguyen Van Trung <trungnv@vn.fujitsu.com>2018-07-26 10:29:41 +0700
commit423225046cd79d46c0f66f60b79733245d965e80 (patch)
treef12f14ac07d93af93f44d23c9e402d9aee850be2
parent40af9848ac9d739632a780d178dd8912e58f0264 (diff)
downloadironic-423225046cd79d46c0f66f60b79733245d965e80.tar.gz
Follow-up to improve pep8 checking with hacking
This patch will make consistency with Nova, Cinder and other projects in openstack. It's going to rename D703 to N323. Change-Id: I3fe63590c72b65b97f120c96f7b566a771c7087c
-rw-r--r--ironic/hacking/checks.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/ironic/hacking/checks.py b/ironic/hacking/checks.py
index 3cdd4c07f..b502af02b 100644
--- a/ironic/hacking/checks.py
+++ b/ironic/hacking/checks.py
@@ -14,7 +14,7 @@
import re
# D703: Found use of _() without explicit import of _!
UNDERSCORE_IMPORT_FILES = []
@@ -48,7 +48,7 @@ def check_explicit_underscore_import(logical_line, filename):
UNDERSCORE_IMPORT_FILES.append(filename)
elif (translated_log.match(logical_line) or
string_translation.match(logical_line)):
- yield(0, "D703: Found use of _() without explicit import of _!")
+ yield(0, "N323: Found use of _() without explicit import of _!")
def factory(register):
@@ -14,7 +14,7 @@
import re
-# D703: Found use of _() without explicit import of _!
+# N323: Found use of _() without explicit import of _!
UNDERSCORE_IMPORT_FILES = []